netapp_ontap.models.mediator_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.mediator_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MediatorResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MediatorResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `bluexp_account_token: str POST`

    BlueXP account token. This field is only applicable to the ONTAP cloud mediator.

  `bluexp_org_id: str POST`

    BlueXP organization ID. This field is only applicable to the ONTAP cloud mediator.

  `ca_certificate: str POST`

    CA certificate for ONTAP Mediator. This is optional if the certificate is already installed.

  `dr_group: MetroclusterDrGroup`

    The dr_group field of the mediator_response_records.

  `ip_address: str GET POST`

    The IP address of the mediator.

    Example: 10.10.10.7

  `local_mediator_connectivity: str GET`

    Indicates the mediator connectivity status of the local cluster. Possible values are connected, unreachable, unusable and down-high-latency. This field is only applicable to the mediators in SnapMirror active sync configuration.

    Example: connected

  `password: str POST`

    The password used to connect to the REST server on the mediator.

    Example: mypassword

  `peer_cluster: ClusterPeer GET POST`

    The peer_cluster field of the mediator_response_records.

  `peer_mediator_connectivity: str GET`

    Indicates the mediator connectivity status of the peer cluster. Possible values are connected, unreachable, unknown and down-high-latency.

    Example: connected

  `port: Size GET POST`

    The REST server's port number on the mediator.

    Example: 31784

  `reachable: bool GET`

    Indicates the connectivity status of the mediator.

    Example: true

  `service_account_client_id: str POST`

    Client ID of the BlueXP service account. This field is only applicable to the ONTAP cloud mediator.

  `service_account_client_secret: str POST`

    Client secret token of the BlueXP service account. This field is only applicable to the ONTAP cloud mediator.

  `strict_cert_validation: bool GET POST PATCH`

    Indicates if strict validation of certificates is performed while making REST API calls to the mediator. This field is only applicable to the ONTAP Cloud Mediator.

    Example: true

  `type: str GET POST`

    Mediator type. This field is only applicable to the mediators in SnapMirror active sync configuration.

    Valid choices:

    - cloud
    - on_prem
  `use_http_proxy_local: bool GET POST PATCH`

    Indicates if the local cluster should use an http-proxy server while making REST API calls to the mediator. This field is only applicable to the ONTAP cloud mediator.

    Example: true

  `use_http_proxy_remote: bool POST PATCH`

    Indicates if the remote cluster should use an http-proxy server while making REST API calls to the mediator. This field is only applicable to the ONTAP cloud mediator.

    Example: true

  `user: str POST`

    The username used to connect to the REST server on the mediator.

    Example: myusername

  `uuid: str GET`

    The unique identifier for the mediator service.